# SwiGLU Channel Mixer

::: linax.channel_mixers.swi_glu.SwiGLUConfig
    options:
      members:
        - build

---

::: linax.channel_mixers.swi_glu.SwiGLU
    options:
      members:
        - __init__
        - __call__
